package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````3!\```````!```````````"4````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*V2`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````)(P`````
M```DC``````````0`````````0````8```#8C0```````-B=````````V)T`
M``````"P!````````-@$`````````!`````````"````!@```/"-````````
M\)T```````#PG0```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```#@BP```````."+````````X(L````````4````````
M`!0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````V(T```````#8
MG0```````-B=````````*`(````````H`@````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`)6(XJDN=;=S2.D++BV[96TN!_7F!````!`````!````1TY5```````$````
M#P`````````1````1@````0````(````()`0`05`!,0H`@$$@(8$A(()```)
M(`0(B(`00;H``H@`````1@```$D```!,````30```%0```!5````5P```%D`
M``!:````6P```%T```!?````8````&(``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@
M:PE#UF:OS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_
MJ9R;X*<""FL:GE"CX/M)``````````````````````````````````````,`
M#`#`'0``````````````````S`(``!$`````````````````````````U0``
M`!(`````````````````````````S0$``!(`````````````````````````
MJ`(``!(`````````````````````````AP```!(`````````````````````
M````3@$``!(`````````````````````````>P(``!(`````````````````
M````````U`$``!(`````````````````````````90$``!(`````````````
M````````````E0$``!(`````````````````````````ZP```!(`````````
M````````````````EP(``!(`````````````````````````L@(``!$`````
M````````````````````@@(``!(`````````````````````````B`$``!(`
M````````````````````````'`$``!(`````````````````````````#`$`
M`!(`````````````````````````_@```!(`````````````````````````
MVP$``!(`````````````````````````Y@$``!(`````````````````````
M````O@$``!(`````````````````````````N@(``!(`````````````````
M`````````0```"``````````````````````````^@$``!(`````````````
M````````````;`$``!(`````````````````````````'0```"``````````
M````````````````*`(``!(`````````````````````````I@$``!(`````
M````````````````````-P```!(`````````````````````````B0(``!(`
M````````````````````````L`(``!$`````````````````````````5```
M`!8`````````````````````````\P$``!(`````````````````````````
M/@$``!(`````````````````````````D`(``!(`````````````````````
M````9P```!(`````````````````````````90(``!(`````````````````
M````````Q````!(`````````````````````````>````!(`````````````
M````````````C0$``!(`````````````````````````J````!(`````````
M````````````````V@```!(`````````````````````````Q0$``!(`````
M````````````````````7@(``!(`````````````````````````[0$``!(`
M````````````````````````,`$``!(`````````````````````````GP$`
M`!(`````````````````````````2`(``!(`````````````````````````
M00(``!$`````````````````````````WP```!(`````````````````````
M````M@$``!(`````````````````````````)P(``!(`````````````````
M````````3P(``"(`````````````````````````DP```!(`````````````
M`````````````P(``!(`````````````````````````X0$``!(`````````
M````````````````;`(``!(`````````````````````````60$``!(`````
M````````````````````&0(``!(`````````````````````````E`,``!(`
M````````````````````````MP```!$`````````````````````````"P(`
M`!(`````````````````````````)0$``!(`````````````````````````
M10```!(`````````````````````````+P(``!(`````````````````````
M````<P(``!(`````````````````````````=P$``!(`````````````````
M````````KP$``!(`````````````````````````G0,``!(`#`"0-```````
M`*@`````````+P0``!(`#``T+@```````*P$````````/`(``!(`#`#`'0``
M`````(P!````````%`,``!(`#`"^)@````````(`````````,@,``!(`#`#@
M,@```````+`!````````500``!(`#`#`)@```````,X!````````%00``!``
M%@"(H@``````````````````)0,``!(`#`".*````````"(`````````2`,`
M`!(`#``*+0```````$X`````````M0,``!$`#0"82@````````0`````````
M\@,``!(`#```2````````-@`````````#00``!(`#`#6)0```````"@`````
M````*@0``!``%@"PH@``````````````````0P0``!(`#`!P+0```````,0`
M````````Q`,``!``%```H```````````````````;`,``!(`#`"P*```````
M``(!````````X`,``!``\?\`J```````````````````/`0``!``%0"(H@``
M````````````````8@0``!$`%`!(H`````````@`````````_0,``!``%0"(
MH@``````````````````R@,``!(`#`!,'P```````"(`````````T0,``!``
M%```H```````````````````(00``!(`#`"L1P```````%0`````````Q@,`
M`"``%```H```````````````````J0,``!``%@"PH@``````````````````
M@@,``!(`#`!8+0```````!@`````````5@,``!(`#`#^)0```````,``````
M````>`,``!(`#`#82````````*X!````````;`0``!(`#`"R*0```````%@#
M`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS
M965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H
M<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R
M<W1R`&UK9&ER`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R
M:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV
M`&QD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?
M0E-37T5.1%]?`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7T1!5$%?
M0D5'24Y?7P!?7V=L;V)A;%]P;VEN=&5R)`!S:&%?=7!D871E`%]?4T1!5$%?
M0D5'24Y?7P!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N
M,S,`1TQ)0D-?,BXR-P```````@`!``,``P`!``$``P`#``,``P`!``,``P`#
M``,``0`!``$``P`#``,``P`!``,``0`!``0``P`!``,``P`!``,``0`#``$`
M`P`!``$``P`!``,``P`#``,``0`#``,``P`!``,`!``#``$``P`#``,``0`#
M``,``0`#``$``0`%``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``,`[@(``!````!`
M````M)&6!@``!0!Y!```$````+.1E@8```0`A`0``!````"'D98&```#`(\$
M`````````0`!`/@"```0`````````(>1E@8```(`CP0```````#8G0``````
M``,`````````;A\```````#@G0````````,``````````B````````#HG0``
M``````,`````````R!\`````````H`````````,``````````*`````````8
MH`````````,`````````^$L````````@H`````````,`````````,$X`````
M```HH`````````,`````````.$X````````PH`````````,`````````0$X`
M```````XH`````````,`````````2$X```````!(H`````````,`````````
M4$X```````"`H@````````,`````````P!T````````HH@````````(````"
M```````````````PH@````````(````,```````````````XH@````````(`
M```.``````````````!`H@````````(````8``````````````!(H@``````
M``(````;``````````````!0H@````````L````A``````````````!8H@``
M``````(````C``````````````!@H@````````(````E``````````````!H
MH@````````(````R``````````````!PH@````````(````V````````````
M``!XH@````````(````^``````````````!@H`````````4````#````````
M``````!HH`````````4````$``````````````!PH`````````4````%````
M``````````!XH`````````4````&``````````````"`H`````````4````'
M``````````````"(H`````````4````(``````````````"0H`````````4`
M```)``````````````"8H`````````4````*``````````````"@H```````
M``4````+``````````````"HH`````````4````-``````````````"PH```
M``````4````/``````````````"XH`````````4````0``````````````#`
MH`````````4````1``````````````#(H`````````4````2````````````
M``#0H`````````4````3``````````````#8H`````````4````4````````
M``````#@H`````````4````5``````````````#HH`````````4````6````
M``````````#PH`````````4````7``````````````#XH`````````4````9
M````````````````H0````````4````:```````````````(H0````````4`
M```<```````````````0H0````````4````=```````````````8H0``````
M``4````>```````````````@H0````````4````?```````````````HH0``
M``````4````B```````````````PH0````````4````D```````````````X
MH0````````4````F``````````````!`H0````````4````G````````````
M``!(H0````````4````H``````````````!0H0````````4````I````````
M``````!8H0````````4````J``````````````!@H0````````4````K````
M``````````!HH0````````4````L``````````````!PH0````````4````M
M``````````````!XH0````````4````N``````````````"`H0````````4`
M```O``````````````"(H0````````4````P``````````````"0H0``````
M``4````Q``````````````"8H0````````4````S``````````````"@H0``
M``````4````T``````````````"HH0````````4````U``````````````"P
MH0````````4````W``````````````"XH0````````4````X````````````
M``#`H0````````4````Y``````````````#(H0````````4````Z````````
M``````#0H0````````4````[``````````````#8H0````````4````\````
M``````````#@H0````````4````]``````````````#HH0````````4````_
M``````````````#PH0````````4```!```````````````#XH0````````4`
M``!!````````````````H@````````4```!"```````````````(H@``````
M``4```!#```````````````0H@````````4```!$```````````````8H@``
M``````4```!%`````````````````````````)>#```S`\-!`[X#8Q,#0_V3
M@@-C$U,3`(.R@@!G``X`%XX```,^#F)G`PX`$P```!>.```#/HYA9P,.`!,`
M```7C@```SX.86<##@`3````%XX```,^CF!G`PX`$P```!>.```#/@Y@9P,.
M`!,````7C@```SZ.7V<##@`3````%XX```,^#E]G`PX`$P```!>.```#/HY>
M9P,.`!,````7C@```SX.7F<##@`3````%XX```,^CEUG`PX`$P```!>.```#
M/@Y=9P,.`!,````7C@```SZ.7&<##@`3````%XX```,^#EQG`PX`$P```!>.
M```#/HY;9P,.`!,````7C@```SX.6V<##@`3````%XX```,^CEIG`PX`$P``
M`!>.```#/@Y:9P,.`!,````7C@```SZ.66<##@`3````%XX```,^#EEG`PX`
M$P```!>.```#/HY89P,.`!,````7C@```SX.6&<##@`3````%XX```,^CE=G
M`PX`$P```!>.```#/@Y79P,.`!,````7C@```SZ.5F<##@`3````%XX```,^
M#E9G`PX`$P```!>.```#/HY59P,.`!,````7C@```SX.56<##@`3````%XX`
M``,^CE1G`PX`$P```!>.```#/@Y49P,.`!,````7C@```SZ.4V<##@`3````
M%XX```,^#E-G`PX`$P```!>.```#/HY29P,.`!,````7C@```SX.4F<##@`3
M````%XX```,^CE%G`PX`$P```!>.```#/@Y19P,.`!,````7C@```SZ.4&<#
M#@`3````%XX```,^#E!G`PX`$P```!>.```#/HY/9P,.`!,````7C@```SX.
M3V<##@`3````%XX```,^CDYG`PX`$P```!>.```#/@Y.9P,.`!,````7C@``
M`SZ.36<##@`3````%XX```,^#DUG`PX`$P```!>.```#/HY,9P,.`!,````7
MC@```SX.3&<##@`3````%XX```,^CDMG`PX`$P```!>.```#/@Y+9P,.`!,`
M```7C@```SZ.2F<##@`3````%XX```,^#DIG`PX`$P```!>.```#/HY)9P,.
M`!,````7C@```SX.26<##@`3````%XX```,^CDAG`PX`$P```!>.```#/@Y(
M9P,.`!,````7C@```SZ.1V<##@`3````%XX```,^#D=G`PX`$P```!>.```#
M/HY&9P,.`!,````=<8;LIN2JAZ+HRN!._)>$``"#M*1%+N@RY`P(,`!H"#[.
MG&`^](%'[_"?^!>&```#-D9$LH47A0```S6E1N\@D$B7AP``@[=G1X/'!P#Q
MSY>'``"#MP=$%X0``!,$A$>2EYAC<DF#1Z=*&P5)``X%D^<W`",%]TKO\)_N
MPF7R1PCDF&$-*:J&&.$7-P``$P=G_1CE%X<```,W1Q\8Z1<W```3!Z?\&.T%
M1V-:]PP;B#<`0H:A!1%'B&&3%S<`MI<%)XCCH07C&0?_FP<&``ALC@>VETJ&
M`4>7!0``DX5%;B.P!P#O\-^]*HDUQ0ALDPE!`N_P_]S.A1<U```3!07-[P!`
M%#'-"&SO\)^W[_!?SB)WG&"YCP%'I>OF8$9DIF3B>4J%!FDE88*`[_!_R1>$
M```3!"0Z".PIQ>_P?]&7AP``@[<G-85F,X='`!AC-I>C"P>D,;<(;._PG[XJ
MB7FW"&@!Q>\0P%9YO\Z%%S4``!,%1;[O```-".A1U>6WD4>YMP5%[_#?NN_P
MG^7O`"`"JH<7A0```S7E,H)E,``3<0'_@48!1PJ([_"?X0*0EY$``).!(8F"
M@```%X4``!,%90V7AP``DX?G#&.(IP"7AP``@[<G*Y'#@H>"@!>%```3!44+
MEX4``).%Q0J)C9/7-4#]D;Z5A869Q9>'``"#M^<HD<."AX*`01$BX!>$```3
M!,0K@T<$``;DA>.7AP``@[='*9''%X4```,UI0&"E^_PO_B%1R,`]`"B8`)D
M00&"@&F_.7$&_"+X)O1*\$[L4NA6Y%K@2<&7AP``@[<'(@.[!P!C"@L&@T<%
M`*J)+HHJB1,'T`.]PV.&YP"#1QD`!0G]^SL).4$#-`L`'<#:A),*T`,BA4J&
MSH7O\'^@LP<D`0GE@\<'`&.`5P.`9*$$=?#B<"*%0G2B=`)YXFE":J)J`FLA
M88*`LX1D08V$!0DC()H`2I3QOP%$X;\!26VW<7$B\2;M!O67A```@[0$&"P`
MG&`^Y8%'*H3O\'_!#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%[_"_H!,U%0`1
MH`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O\+_*,7%.[0;](ODF]4KQ4NF7B0``
M@[D)$H.W"0`^Y8%'"<6#1P4`*H29[RIG@[<)`+F/`4?QX^IP2G2J=`IYZFE*
M:BEA@H#O\#_%JH1YW2:%[_"?ES7-@T8U`1,)-0&;AB;]@>:#1AD`_=(#1S4!
M&P<G_37'(H7O\#^3*HI*A>_POY([!:H`"27O\!^3RH<BAY<V``"3AH:1?5:%
M12J)[_"_NRP`2H7O\#^?_5=C"/4`XD>]9A%G]8]CC.<"2H7O\+^92H7O\%^H
M)H7O\/^/0?4FA>_P?YTBA>_P'Y:YMP-'&0`;!R?]6?<#1RD`+=-9MTJ%[_`?
M\?&W[_`?NQUQHNC!<D%D3OQ2^%KPANRFY,K@5O1>[&+H$P>$`!:1"I<7BP``
M`SLK`8,W"P`<XX%'"4:!12J*[_!?GY,)]?\3U_E#09.SA^D`PA?!DYF/LXGY
M0&/!"0K!>I.$"O^3!P0!II?!:[.$)P"A"QU,%XD``!,):=H!1LZ%4H7O\!^;
M7H:FA5*%[_!_J`$E8W*L!A,$A?\FE&-VE`"9J'T48VF4!"%&RH4BA>_P7Y5E
M^<%W06?!%T$'/I>S!R<`'8PS!30!P6>A!XJ7F&.#-PL`N8\!1X7GP6(6D>9@
M1F2F9`9IXGE">J)Z`GOB:T)L)6&"@-:9XY)9^7U5Z;?O\#^K77%6[/UWA6K]
M<N$7$X<*`:+@)OQ*^$[T4O"&Y#Z7%I&NB;,%)P`3AXH`"I<%9!>)```#.8GP
M*HH3!O3_%R4``!,%I7>#-PD`'..!1^_P/X.;!`4`8UZ0`!.'"@$*ES,$AT";
MA_3_/I0#1X3_*>.=[Y>'``"#M^?N3H;2A9*7B&/O\._ZA6>A!XJ7F&.#-PD`
MN8\!1[GGA6(6D:9@!F3B=$)YHGD">N)J86&"@+Z$?72%9V$4P0>BES.$)P`F
MAI,%\`(BA>_POXY%U9>'``"#MT?IIH8BAI*7B&/2A>_P/X95M^_PWYP=<:+H
MIN3*X%+XANQ._%;T6O!>[&+H@\<%`!>)```#.6GCJH23AS?\D[<7`#.$]0`B
MA8,W"0`^Y(%'[_#OZ"J*3``FA>_PG[YIS:J)[_#/YV-X10N22A>+```#.ZO@
MC@H#QP0`IH>3!M`#8P8'$F,&UP`#QQ<`A0=]^X6?@SD+`!,%*@`^E=:9[_`/
MY2.PJ0`QQ0,W"P"#QP0`$X44`%:7%&,3!M`#(X#V`('KC:B#1P4`!06C`/<`
MO<,VAX4&XYC'_I,&T`.3!Q<`(P#7``-'!`"%!P4$HX_G_G7[(F>#-PD`N8\!
M1\WOYF!&9*9D!FGB>4)ZHGH">^)K0FPE88*`@T<$`(4)!02CC_G^X=N#1P0`
MA0D%!*./^?[]\\&W-H=-MQ>+```#.^O3`SP+`(,W#`"EQ^*'@4F89\Z&H0>%
M*67_C2:3E38`EX<``).'!]>80P7K!4<NA9C#[_#OUZJ+-=V3FCD`5H;BA>_P
M[_`C,'L!FX<9`(X'OILCL`L`3L+%M6*%[_!/^2,PJP"JBSG5DYHY`/F_@4?5
MM<%%@4EMM^_PGX)!$2+@%X0```,T!,T&Y)=F``"3AF9CLP=$`(AC%X8```,V
M!LR7)0``DX6%4>_PC_L2E`A@`F2B8!<W```3!T>&@4>ZAA<6```3!@;2ER4`
M`).%!5%!`6_P[^*7AP``@[>GQY=F``"3AB9>%X8```,V)L>2EXACER4``).%
M94QO\&_V77%*^/ER"6F&Y*+@)OQ.]!,'B0$6D0J7EXD``(.Y*<&#MPD`'..!
M1^_PK]IY="$4DP<)`J*7,X0G``5F*H>7)P``DX='2Y<F``"3AD9+!0:%12*%
M[_#O[_UTP123!PD"II>SA"<`(H4%9J:%[_!OT!L$!0!C1`0$&P44`._P;\,J
MB0W-(H:FA4J4[_"/TR,`!`")9^$'BI>88X.W"0"YCP%'F>N)8A:1IF!*A09D
MXG1">:)Y86&"@._PK^X!2=&_@;=1<=+AA69]>OUR$P=*]Y.'!@FB\:;MRNE>
M]8;USN56_5KY8O%F[;J7%I$3AX8("I>7BP``@[N+LRJ)+H07)0``$P5%0;.%
M)P"#MPL`'..!1^_P7X^JA),%\`)*A>_P3]0YP1<E```3!>4_RH7O\-_*2H6%
M9Y.'APB*EYAC@[<+`+F/`4=CDP<4A6(6D:YP#G3N9$YIKFD.:NIZ2GNJ>PI\
MZFQM88*`(H7O\(_2ER4``).%13SO\,^M*H1%U85GDPF*_Q.'!PE.E[,))P`3
MAP<)DX<'"8J7A6HSC%=!@T<$`!,*BO=2EQ<K```3"RLY,PHG`,'/D<2BA2:%
M[_!OPBW)(H7O\.^MDP?U_Z*7JHR3!O`"8VCT`#&H(X`'`/T78P;T``/'!P#C
M"=?^(H7O\$^KJHQ*A>_PSZIFE04%XW-5\X5%2HC:AR*'ER8``).&AC,%9DZ%
M[_#/T]*%3H7O\$^W`>F#)XSXO68A9_6/8X_G`I<E``"3A04P`47O\&^A*H3C
M`07N@T<$`+7WD<2#QP0`FX<G_9G'A4P7)```$P0$*TF_@\<4`.G7_;>%14Z%
M[_`OIUW]SH47)0``$P6E*N_PO[5.A>_PS\!MM>_P;]%!$9,%\`(BX`;D*H3O
M\&_"&<$3!!4`(H4"9*)@00%O\$^^>7&%9_UR2N@&]"+P)NP3AX<`%I$7B0``
M`SE)E@J7@S<)`!SC@4=-P8-'!0"JA,G/[_`/G!,&%0"%9RJ$8^_'"GUW81?!
M![J7,X<G`*:%.H7O\`^LDP?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#QP<`
MXPG7_GUTA6=A%,$'HI<SA"<`DP7P`B*%[_!ON`W-8V*D!GUUA6=A%<$'JI<S
MA2<`[_#OLX5GH0>*EYAC@S<)`+F/`4>AYX5B%I&B<`)TXF1":45A@H"%9Z$'
MBI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7)0``$P4E%T5A;_`/KR,`!0!Q
MOP%%;;?O\"^_.7$B^";T2O!.[`;\EX0``(.TI(:<8#[D@4=``!<I```3":D7
MEXD``(.Y*8:BA4J%[_`OXA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*
MA>_P#^!E\1<I```3">D4EXD``(.Y:8*BA4J%[_!OWA7!$D>#MPD`#@>ZEYAG
MF.-EUYAKH0>8XVW_HH5*A>_P3]QE\1<I```3":D1EWD``(.YJ7ZBA4J%[_"O
MVA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PC]AE\1<I```3">D.
MEWD``(.YZ7JBA4J%[_#OUA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*
MA>_PS]1E\1<I```3":D+EWD``(.Y*7>BA4J%[_`OTQ7!$D>#MPD`#@>ZEYAG
MF.-EUYAKH0>8XVW_HH5*A>_P#]%E\1<I```3">D(EWD``(.Y:7.BA4J%[_!O
MSQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P3\UE\1<I```3":G]
MEWD``(.YJ6^BA4J%[_"ORQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*
MA>_PC\EE\1<I```3"6D"EWD``(.YZ6NBA4J%[_#OQQ7!$D>#MPD`#@>ZEYAG
MF.-EUYAKH0>8XVW_HH5*A>_PS\5E\1<I```3":G_EWD``(.Y*6BBA4J%[_`O
MQ!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P#\)E\1<I```3">G\
MEWD``(.Y:62BA4J%[_!OP!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*
MA>_P3[YE\1<I```3":GOEWD``(.YJ6"BA4J%[_"OO!7!$D>#MPD`#@>ZEYAG
MF.-EUYAKH0>8XVW_HH5*A>_PC[IE\:*%%R4``!,%1?;O\(^YJH49Q1<E```3
M!47S[_#/]:*%%R4``!,%Y?7O\*^WJH49Q1<E```3!67V[_#O\Z*%%R4``!,%
MA?;O\,^UJH4%S1<E```3!07F[_`/\B)GG&"YCP%'J>-"=.)PHG0">>)IER4`
M`).%!?87)0``$P4%ZB%A;_!O[Z*%%R4``!,%!?/O\$^QJH5YT1<E```3!07J
M[_"/[66_[_"OB0$1(N@&[!=T```#-(113``7)0``$P7EYQQ@/N2!1^_PSZT5
MP8-'!0`!18G'DX<'_3,U\``B9QQ@N8\!1YGGXF!"9`5A@H`!1?6W[_#/A$$1
M!N3OX%_3`27OX/_]$<$(8:)@00&"@#EQ)O1*\`;\(OA.[!=Y```#.<E*JH1,
M`!<E```3!07K@S<)`#[D@4?O\,^F%<6#1P4`*H25PZ:%[^"?V2G!(F>#-PD`
MN8\!1Z7OXG!"=*)T`GGB:2%A@H`B9X,W"0"YCP%'IH6Q[T)TXG"B=`)YXFD7
M)0``$P6%Y2%A;_#OWB:%[^`?RZJ)(H7OX)_*3I4)!>_@'\LBB)<G``"3AZ?2
M)H>%19<F``"3AN;2?58JA._@/_,B9X,W"0"YCP%'HH7%U^_@'_>7=P``DX='
M'65Q@[@'`0.XAP&0<Y1WF'N<?\KZSO;2\@;G(N.F_M;NVNK>YN+B%WH```,Z
M:CP#,PH`&OX!0Q<C```3`^/=$PG!`;[\ER<``).'A]VJB1KP/OP7(P``$P.C
MQY<G``"3AZ?<RH47)0``$P4%QQKT`OC&Z,+LLO"V]+KXON""Y._PKY01Q8-'
M!0`JA&.0!S+OX'^\`27OX!_G8P\%%`!A8PP$%"*%[^`?O`8%!07OX)^\`T<$
M`*J$JHH%PQ<K```3"ZO7)H7:AGU6A44%!._@G^0#1P0`B01U]X0(%R4``!,%
M)<XAH(ADH00-P<J%[_#/C2J$;=F#1P4`]=?O\*^6?=$BA>_@/]4JA!GM!!"`
M8`',@T<$`&./!PPBA>_PKY1QX8!DH01U]"*%[^#?LZJ$5H7OX%^SJ9R;A$1`
M)H7OX)^SUHB7)P``DX>GNQ<H```3""C/(H>7)@``DX8&SWU6A46JBN_@/]N3
M!0`<5H7OX)_,_5=C&/4`[^#_L1Q!14=CEN<@#`%6A>_@_]`JA!GERD>]9A%G
M]8]C@N<*EW<``(.W)RF#M@D`B&-6AQ<F```3!J;.A47OX!_4@41R=X,W"@"Y
MCP%'8YX'++I@&F16>;9Y%GKV:E9KMFL6;":%]G1988*`(H7OX!_'*H2A!.,`
M!?(=OP%$#;]B=208&<G*A>_@O_P!Q8-'!0"%XXADH01]]35%[^`_IJJ$JHH7
M)```$P0DOQ,',`51O>_@W\(JA''=[^!?HP8%!065O6I+[^"?H9L'!0#C&_OT
MRD<3!P`<D_?W'^.4Y_0FA>_@WZ'*A:J$%R4``!,%Q<COX!_VJH5C!046`[4)
M`._P[^"JBV,.!11>A>_@/YX;"P4`C4=CV&<#$P7+_Y<E``"3A07&7I7OX'^P
M">V11V,'^QR;![O_WI<#QP<`DP?P`F,.]QK*A1<E```3!>6I[^`_\&,*!1"#
M1P4`8X8'$!,'``-C@N<0ER4``).%9;$7)0``$P5EI^_P[ZKOX#^J*HB7*```
MDXA(SI<G``"3A\>?5H>7)@``DX:FP'U6A44FA>_@W[]]6<5)%RP``!,,S,N7
M*P``DXM+G1<K```3"TN_):#OX+^5'$%CES<#[^`?I04D*HABX**(WH=6A]J&
M?5:%12:%[^"?NY,%`!PFA>_@_ZSC""7]5H7OX%^IIH47)0``$P7EE>_P[Z$F
MA>_P'[L-O1=W```#-R<*@[8)``AC%R8``!,&QJM6AX5%[^`?M0&][_"_N')W
M@S<*`+F/`4=CE`<.(H4:9+I@]G16>;9Y%GKV:E9KMFL6;%EA;^`?J(.["0!5
MM8%%7H7OX#^Y*HGC"P7N[^#?_*J)XT8%[I,%9?\!1DJ%[^!_GA,+`1`91MJ%
M2H7OX)^K`R<!$+='04.3AP<PXQ'W[`-701"19Y.'AU3C&O?JDX7I_`%&2H7O
MX/^:(`*BA1,&@`)*A>_@'ZB7*```DXA(N2*(ER<``).'IXI6AY<F``"3AH:J
M?5:%12:%(P@!$N_@?ZKUO8.YB0#C@@GD3H7OX&_^C4?C_*?B<167)0``DX4E
MITZ5[^`?D>,2!>+.BSF][^!?K#EQ(O@7=````S3$]DKP3NP&_";T4NBS!T0`
MA&.3"4$`%WD```,YB?*#QP0+SH47)0``$P6EA@,W"0`ZY`%'HXCT"N_@/\X9
MQ0-'!0"3!Q`#8POW$N_P[^>S!T0`A&,FA8U&!4:7)0``DX5%H^_@3_RJA!W!
M'&DS!T0`"&.,8Q<F```3!B:B[^"O^YQHC&/<1=F#A8MCE@<0LP=$`(ACC48%
M1I<E``"3A66@[^!O^*J$%WH``!,*"O`-P<Z%%Q4``!,%17COX!_&*H9YP9QH
M,P=$``ACC&/OX*_VLP=$`(1C!4:7)0``DX7EG":%[^!/ZJJ%%R8``!,&9ITF
MA>_@3_02E!Q@SH47%0``$P6E<J.(!PKOX#_!(SBJ`"J$.<63!0`<(H7OX-^&
M&P<5`(5'8_#G`L5'8PWU`(,WB@"JAB*&C&,7)0``$P5EF^_@?XLB9X,W"0"Y
MCP%'L>OB<$)THG0">>)I0FHA88*``S6*`._P?YXC.*H`*H1=\1<E```3!665
M[^#_AX-'%0#CB@?LV;4#-XH`G&@,8XAC[^"?YS6_LP=$`(AC[^"_@OVU[^!?
MD7EQ(O`F[$KH!O07>0```SGIV(,W"0`^Y(%'JH3O\$_`DP7P`BJ$[^"_@!G!
M$P05`"*%[^#O_"J$3``7%0``$P7E;._@/[,!S8-'!0")RQ,'``-CAN<`@<2#
MQP0`B>\B9X,W"0"YCP%'E>^B<`)TXF1":45A@H`11I<5``"3A05W(H7OX._4
M8?TB9X,W"0"YCP%'B>L"=*)P0FDFA>)D16%OX+^\[^#?AA,!`=,C,($L(S01
M+",\D2HC."$K(S0Q*R,P02LC/%$I%W0```,T!,TT`'U?P6X<8",T\2B!1Y,(
MA0.3`H4'-H@37P\"MP__`)..#O`#M@@`00BA")-5!@(3%X8!DQ.&`)-7A@(3
M7H8`DU2&`Q.3A0$S=^<!L_/S`;/WUP$S9W<`,W[>`<6/,W/C`:(%,V?'`1M6
MA@&SYV<`L_7U`5&/S8\C..C^(SSX_N.2$OO]5<9_9G\*9^)N`GXB<\)X8GB&
M8Y.$!B"!D1&@LH.P8IQBNH*A!K&/L\?W`;/'UP$3EQ<`_8-=CVV/N/[ZC_*.
M%H\:CD:#PH@>B..9EOR#/@4`HF\#.`4!`S.%`(,XA0$#/@4"-X>"6A,'EYF3
MU[X!$Y9>`%V.NI\37R,`DQ?C`6V.\I^S1A@!L^?G`;/V9@!^EL)O,_^W`+/&
M%@$VEK-&Z`%MCK/VU@&ZGY,25@"35+8!QI^SQ@8!_I:S[Y(`$]DN`).3[@'^
MEN)OL^,C`;/'=P#QC[J?[8ZSQ^<!PI^3E%8`$]FV`9,2Y@'^EPF"@G^SXL(`
M,^8D`;*7,\93`+J?L_.S`'6.[8]^GS-&=@"3E%<`$]FW`9.?Y@%ZEHF"(G^S
M[]\`L^8D`3:6L\;R`6V.L_*R`/V..I\>GY,45@`36;8!L\96`).3YP&)@[/C
M\P#ZEK/G)`&^EC/_M@#"=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>S
MYB0!MI>3$N8!"8*SXL(`,_:W`.)WL\93`+/VY@&S\[,`NI?^EY,45@`36;8!
ML\9V`+Z6L^<D`;Z6DQ_O`1-?+P"S[^\!,_^V`(9FL\?R`?&/L_*R`+J6GI:3
M%%\`$UF_`;/'5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`IF>SQG\`L_;F`;/_
MOP"ZEY:7DQ16`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/BX@$S_[8`QF:S
MQU,`\8^S\[,`NI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/V
MMP#F9[/&\@&S]N8!L_*R`+J7GI>3%%8`$UFV`;/&5@"^EK/G)`&^EI,3[P$3
M7R\`L^/C`3/_M@"&=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>SYB0!
MMI>3$N8!"8*SXL(`,_:W`*9WL\93`+/VY@&S\[,`NI?^EY,45@`36;8!L\9V
M`+Z6L^<D`;Z6DQ_O`1-?+P"S[^\!,_^V`,9VL\?R`?&/L_*R`+J6GI:3%%\`
M$UF_`;/'5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`YG>SQG\`L_;F`;/_OP"Z
MEY:7DQ16`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/BX@$S_[8`BF:SQU,`
M\8^S\[,`NI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/VMP"J
M9[/&\@&S]N8!L_*R`+J7GI>35+8!DQ-6`+/&5@`3&>\!OI837R\`L^>3`,IC
M,V_I`;Z6L\?O`>V.L_^_`+J3\8^>DI/4M@&SQ_<!DY-6`+/CDP"6E^IDDQ+F
M`0F"L^+"`)Z7[8\S1E\`NI0S?[\`$]FW`76.DY-7`*:?,T;F`;/C(P&S\[,`
M?I:3G^8!B8(>EK/OWP`*>;-TM@"SQO(!_8ZS\K(`DY-4`)/9M`$ZF3/'5@"S
MYC,!DY/G`8F#L^/S`$J?L\=_`.V.>I>QCRIV,P_7`#?WV6X3!Q>ZLWF_`!/9
MN0$ZEI.660`6ENV/L^8F`;*7[8Z^EI.2Y`'*=XF`L^*2`#/YM@`SQE,`L_^_
M`)-4N0&ZES-/Y@$3%ED`,W^_`/Z718[ZEVV./I:3G^D!ZG>3V2D`L^\_`;-T
MM@`SS_(!L_.S`)/9M`&ZES-/WP"3EE0`,W^_`)Z7L^8V`?J7[8Z^EA,?Z0&.
M9Q-9*0`S;R\!L_.V`#/)[P&S^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!
MEI=MCCZ6DY+D`:YGB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S
M_[\`SI>SYB8!_I?MCKZ6DY_C`<YGD],C`+/O?P`SR?(!L_.V`+-YOP"ZES-/
MR0`3V;,!$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0![F>)@#-OGP`SR>\!LW2V
M`+/YL@"ZE[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6E^V.OI:3DN,!CG>3TR,`
ML^)R`#-)7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`L_^_`,Z7,V8F`?Z7;8X^
MEI.?Y`&N=XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9`!/9M`&3EE0`,W^_`,Z7
ML^8F`?J7[8Z^EA.?XP'.=Y/3(P`S;W\`,\GO`;/SM@"S^;(`NI>S0LD`$]FS
M`1.64P"S\K(`SI<S9B8!EI=MCCZ6DY+D`>YWB8"SXI(`,TE?`+-TM@"S^;\`
MNI>S3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`9)GD],C`+/O?P`S
MR?(!L_.V`+-YOP"ZES-/R0`3V;,!$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0!
MLF>)@#-OGP`SR>\!LW2V`+/YL@"ZE[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6
ME^V.OI:3DN,!TF>3TR,`L^)R`#-)7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`
ML_^_`,Z7,V8F`?Z7;8X^EI.?Y`'R9XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9
M`!/9M`&3EE0`,W^_`,Z7L^8F`?J7[8Z^EA.?XP&2=Y/3(P`S;W\`,\GO`;/S
MM@"S^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6DY+D`;)WB8"S
MXI(`,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6
MDY_C`=)WD],C`+/O?P`S^;8`L\/R`;-YOP"ZES//PP"34[D!$Q99`#-_OP#.
MES-F=@!MCOJ7,X_'`).3Y`'R=XF`L^.3`#/&?P"S=+\`L_*R`+J7L8[MCI/9
MM`&6EY.25`"VE[/F,@&VEQ,6Z0&69A-9*0`S9B8!,\G#`+/RMP"S_[\`NI8S
M1^D!;8_^EA.94@"3W[(!,VGY`;J6RI83G^0!B8`S;Y\`_5>S=+8`-_?&(_6-
MMF:!DPH'$P?'S;-__P`S9N8!,_GT`;J6,W96`+/S\P"VDY/9M0$S9B8!$YE5
M`!Z6LV,Y`1Z6LW/V`).6X@%69I/2(@"SYE8`L_+V`#-OWP`S^5\`.I8S?[\`
MLI23V;,!,V\O`1.94P`FG[-D.0$3EN4!)I^)@?9D38ZS=?8`T8XS?_\`,_FR
M`+/V=@"ZE/Z4DUF_`;/F)@$3&5\`II:S9#D!$YKC`9/?(P"FEI9TLV_Z`;/S
M_P`S9O8!_8XS^74`NI0S=N8!II(S9B8!DY16`!/9M@&SY"0!%I:3&>\!)I83
M7R\`MG0S[^D!LW+_`+/O[P%]CC/Y4P"S_]\`NI2S[R\!KI03&58`DUFV`9.5
MY@&)@M6-LX:?`+-O.0'^EM9_L_3U`#-OOP#]CC/YD@"ZGS-_SP`S;R\!_I,3
MF58`D]FV`9,?Y@$)@K/OSP`S!G\`,V\Y`7J6=G^S\_\`L^7U`7V.,_ET`#J?
M]8VSY24!^I(3&58`DUFV`1.?Y@&)@C-OWP"SAE4`LV4Y`:Z6FF6S<O\`L^_O
M`?V.,_E3`+J5L__/`+/O+P&NE!.95@"3V;8!DQ7F`0F"T8TSAI\`LV\Y`7Z6
MNF^S]/4`,V^_`'V.,_F2`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?
M`+,&?P`S;SD!^I9:;[/S_P"SY?4!_8XS^70`.I_QC;/E)0'ZDA.95@"3V;8!
M$Q_F`0F",V_/`#.&50"S93D!+I;Z9;-R_P"S[^\!?8XS^5,`NI6S_]\`L^\O
M`:Z4$QE6`)-9M@&3E>8!B8+5C;.&GP"S;SD!_I::?[/T]0`S;[\`_8XS^9(`
MNI\S?\\`,V\O`?Z3$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZECI_L_/_
M`+/E]0%]CC/Y=``ZG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E
M.0&NEMIULW+_`+/O[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)
M@M&-,X:?`+-D.0$FEOITL__U`#-OOP!]CC/Y\@$S?]\`NI0S;R\!GI03&58`
MDUFV`9.3Y@&)@K/CTP"S!I\`LV0Y`1YI,__S`+/E=0"FEO&-L_3O`3J9_8X6
MF<6-DYE6`!/:M@&34B8`DQ3F`<J5/FFSY%0`,^9)`;/R]`"RE3/FDP!UCK/S
M]0`ZF;-U7P!^F9.94P`3VK,!38Z3WR8`DY7F`4J6L^9)`;/E]0$VEK/FM`"S
M=/8`7F:S__4`,_GR`;/V=@`ZEGJ6L^8F`1.?5``3V;0!,V\O`;*6^I83EN,!
M?F^3TR,`,V9V`+-S]@#1C?V.,_I_`.6-.I^3V;8!%I\3F58`L^5%`3-I.0'Z
ME9YY$]\D`).2Y`&SXN(!,__R`#-Y^0`S9E8`RI5UCK/ZXP&ZF;/T]0`S9U8!
M,X;Y`3*7$YE4`!/6)@`3VK0!DY_F`;/OSP`S:4D!L\;R`3-Y^0`ZF:V.-[>8
M,KYU"@<3!V<=LWGY`)/2N0&ZE1.660">E?V.,V96`'V.KI:3DN0!WG.)@+.%
MQ@"SXI(`,\9?`+/T]0"ZDS-&)@&3EE0`$]FT`1Z??8ZSYB8!_8YZEC:6DY/I
M`?YVD]DI`+/C,P$S>?8`,\]R`+/__P"36;D!NI8S3[\`DQ59`#-__P#^EK/E
M-0'ZEOV-MI43G^0!@S8!((F`,V^?`+//XP&S]/4`L_+R`)/9M`&ZEK//SP`3
MEE0`L___`):6,V8V`?Z6?8XVEI,2Z0&#-H$@$UDI`+/B(@&S3U\`,WGV`+/S
M\P"36;D!NI:SS[\`DQ59`+/__P">EK/E-0'^EOV-MI63G^0!@S8!(8F`L^^?
M`+/#\@&S]/4`LWG_`+J6,\_#`)/3M`$3EE0`,W__`,Z6,V9V`/J6?8XVEA,?
MZ0&#-H$A$UDI`#-O+P&S<_8`,\GO`;/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.
MEK/E)0&6EOV-MI63DN0!@S8!(HF`L^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9
MM`$3EE0`L___`,Z6,V8F`?Z6?8XVEI.?XP&#-H$BD],C`+/O?P`SR?(!LW/V
M`+-Y_P"ZEC-/N0`3V;,!DY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!(XF`
M,V^?`#/)[P&S]/4`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6?8XV
MEI.2XP&#-H$CD],C`+/B<@`S25\`LW/V`+/Y_P"ZEK-/N0`3V;,!DY53`+/_
M_P#.EK/E)0'^EOV-MI63G^0!@S8!)(F`L^^?`#/)\@&S]/4`LWG_`+J6,T_)
M`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#-H$DD],C`#-O?P`SR>\!
MLW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E)0&6EOV-MI63DN0!@S8!
M)8F`L^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F`?Z6
M?8XVEI.?XP&#-H$ED],C`+/O?P`SR?(!LW/V`+-Y_P"ZEC-/N0`3V;,!DY53
M`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!)HF`,V^?`#/Y]0"SQ.\!L_GR`+J6
ML\+$`)-4N0$3%ED`L_+R`,Z618Z6EGV.-I:3E.,!@S:!)I/3(P"SY'0`LT*?
M`+-S]@"S^?\`NI:SS[(`D]*S`9.54P"S__\`SI:SY54`_8W^EK./M@"3$ND!
M@S8!)Q-9*0"SXB(!L\54`#/Y_P`S?_\`DUFY`;J6L8T3%ED`_8WZEC-F-@%]
MCJZ6LX7&`!.?XP$#-H$GD],C`#-O?P"SQN(!L_/U`/V,.I:SQO8!_8XFEI/9
MLP&3E%,`-I:SYC0!-I:#-@$HDQ_I`1-9*0"S[R\!NI:S1/\!,W?V`/:6L_+R
M`#/&M`!]CI,55P"37K<!EI:REC/FU0&3E>,!D],C`+*6L^5U`/V..I,S!L\!
M,X<%`;.%'P%]CQ3A_8VS=O,`\8\8Z1SQ%.4,[0,W@2@<8+F/`4>5XX,P@2P#
M-`$L@S2!*P,Y`2N#.8$J`SH!*H,Z@2D3`0$M@H#OT(_?01$3!0`(!N3OT,^O
MMW9=3(8&DX;FSS=WZ6$W)D5G%.D3!A8PMU8R$`8'$.&3AF9'%T8```,VQC\3
M!P<?$.44[1CQ(S0%`B,X!0(C+`4&HF!!`8*`.7$B^";T2O!2Z`;\3NQ6Y!AU
MDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7U@$VEYSTF/@RB2Z$$XJ$`S'MDP?P
M`V/:)PD;"0G\FUII`)N)&@":":*9HH43!@`$4H7OT$^V$P0$!":%[^`_S>,5
M-/^;FFH`.PE904J&SH52A>_03[0CK"0'XG!"=*)T`GGB:4)JHFHA88*`DPD`
M!+N'J4"^B6-(]@*;B@D`5H:BA5*5[]`OL;Q<$P<`!+N&^0"TW..3YOPFA3L)
M.4%6E._@_\:]M[*)R;^BB46W>7$B\";L4N`&]$KH3N2#N84"$XJ%`Y,&`/@3
MUCD`$W;V`S,'R@"3!Q8``[D%`R,`UP`3!X`#JH0NA`4F,P7Z`&-5]Q*3!P`$
MD9\11V/SYQ0)1V/WYQ)CD@<2(H7OX%_`$P:``X%%4H7OT`^]DU8)`1-7B0"3
M]O8/H@:;5XD!$W?W#T('U8\3>?D/8@G9CQO6B0&3U@D!`A:SYR<!$]>)`)/V
M]@^B%M&/$W?W#T(7U8_9C^(9L^<W`2*%//COX%^Z'&`BA>&#(X#T`!Q@P8.C
M@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T`!QDP8.C@O0`'&2A@R.#]``<9*.#
M]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%]``<:*.%]``<;.&#(X;T`!QLP8.C
MAO0`'&RA@R.']``<;*.']``<<.&#(XCT`!QPP8.CB/0`''"A@R.)]``<<*.)
M]``"=*)PXF1"::)I`FI%86_0+Z"3!X`#.X;'0(%%[]!/K-6](P`%`/&](P`%
M`*,`!0#Y%PD%XX<'[.VW(P`%`*,`!0`C`04`HP$%`/$7"4<1!>/GY^K1OY=6
M``"#MJ97;]`OC0````````$``@``````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z
M.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S```````N````````
M`%!!4E]414U0``````````!005)?4%)/1TY!344`````.@`````````O````
M`````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`
M`````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$````
M``!005)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``
M``````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)
M4@````````!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X``````````#$`````````3$1?3$E"4D%265]0051(`%-9
M4U1%30``+W1M<`````!54T52`````%5315).04U%```````````E,#)X````
M`'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%4
M2`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP
M+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`
M````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U.````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```````````M90```````"TM````````5$U01$E2``!4
M14U01$E2`%1%35``````5$U0``````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.
M('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I
M>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*
M)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M
M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D
M<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]4
M13H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D
M<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F
M+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@
M)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ
M.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U
M;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E
M($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R
M7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!8
M6%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE
M;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN
M"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]
M("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D[
M"F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@
M/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T
M7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G
M/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@
M9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I
M="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P
M;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P
M*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'
M24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S
M*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP
M0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP
M0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T
M($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P
M.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S
M970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A
M<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR
M96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A
M8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92![
M"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`
M24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U
M;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@
M)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI
M.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^
M>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B
M=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F
M=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@
M34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@
M("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E
M(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`]
M(#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R
M(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E
M<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD
M9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T
M<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM
M>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@
M;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A
M=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*
M)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)
M3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E
M;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@
M(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*
M?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@
M>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE
M9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D
M9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I
M>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I
M+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T
M97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP
M(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@
M>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D
M1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D
M8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?
M;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ
M93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B
M.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L
M("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R
M7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M
M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^
M.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F
M("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA
M;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@
M)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E
M=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I
M.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D
M<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%2
M7TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)0
M05)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF
M(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M`'!E<FQX<VDN8P``````````0T%#2$4``(FKS>\``````1L#.Q0````!````
M;)/__RP`````````$``````````#>E(``7P!`1L-`@`0````&````#B3__\B
M``````<!````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````0````````#>`@````````$`````````
M[@(````````!`````````/@"````````(`````````#8G0```````"$`````
M````"``````````9`````````."=````````&P`````````(`````````!H`
M````````Z)T````````<``````````@`````````]?[_;P````#8`@``````
M``4`````````"`T````````&`````````,`#````````"@````````":!```
M``````L`````````&``````````5`````````````````````P````````!0
MH`````````(`````````0`4````````4``````````<`````````%P``````
M``#8%`````````<`````````R!(````````(`````````%`'````````"0``
M```````8`````````!X`````````"`````````#[__]O``````$```@`````
M_O__;P````!H$@```````/___V\``````@````````#P__]O`````*(1````
M````^?__;P`````+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````*4$%2+G!M"@``````````````````````````
M``````````````````````````````````````````````````````````#_
M_________P``````````(!H````````@&@```````"`:````````(!H`````
M```@&@```````"`:````````(!H````````@&@```````"`:````````(!H`
M```````@&@```````"`:````````(!H````````@&@```````"`:````````
M(!H````````@&@```````"`:````````(!H````````@&@```````"`:````
M````(!H````````@&@```````"`:````````(!H````````@&@```````"`:
M````````(!H````````@&@```````"`:````````(!H````````@&@``````
M`"`:````````(!H````````@&@```````"`:````````(!H````````@&@``
M`````"`:````````(!H````````@&@```````"`:````````(!H````````@
M&@```````"`:````````(!H````````@&@```````"`:````````(!H`````
M```@&@```````"`:````````(!H````````@&@```````"`:````````(!H`
M```````@&@```````/"=````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1T-#.B`H56)U;G1U(#$R+C,N
M,"TS=6)U;G1U,2D@,3(N,RXP`$%2````<FES8W8``4@````$$`5R=C8T:3)P
M,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?>FEF96YC96DR
M<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL
M9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP
M;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N<')E
M:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N
M9&%T80`N9V]T`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T=')I8G5T97,`````
M````````````````````````````````````````````````````````````
M```````````````````````+`````0````(`````````<`(```````!P`@``
M`````"$````````````````````!````````````````````$P````<````"
M`````````)0"````````E`(````````D````````````````````!```````
M`````````````"8````'`````@````````"X`@```````+@"````````(```
M``````````````````0````````````````````T````]O__;P(`````````
MV`(```````#8`@```````.@`````````!0`````````(````````````````
M````/@````L````"`````````,`#````````P`,```````!("0````````8`
M```"````"``````````8`````````$8````#`````@`````````(#0``````
M``@-````````F@0```````````````````$```````````````````!.````
M____;P(`````````HA$```````"B$0```````,8`````````!0`````````"
M``````````(`````````6P```/[__V\"`````````&@2````````:!(`````
M``!@``````````8````"````"````````````````````&H````$`````@``
M``````#($@```````,@2````````$`(````````%``````````@`````````
M&`````````!T````!````$(`````````V!0```````#8%````````$`%````
M````!0```!4````(`````````!@`````````>0````$````&`````````"`:
M````````(!H```````"@`P``````````````````$``````````0````````
M`'X````!````!@````````#`'0```````,`=````````TBP`````````````
M``````0```````````````````"$`````0````(`````````F$H```````"8
M2@```````$A!```````````````````(````````````````````C`````$`
M```"`````````."+````````X(L````````4````````````````````!```
M`````````````````)H````!`````@````````#XBP```````/B+````````
M+`````````````````````@```````````````````"D````$`````,`````
M````V)T```````#8C0````````@````````````````````!``````````@`
M````````LP````X````#`````````."=````````X(T````````(````````
M````````````"``````````(`````````+\````/`````P````````#HG0``
M`````.B-````````"`````````````````````@`````````"`````````#+
M````!@````,`````````\)T```````#PC0```````!`"````````!@``````
M```(`````````!``````````U`````$````#``````````"@`````````)``
M``````!0````````````````````"````````````````````-H````!````
M`P````````!0H````````%"0````````.`(```````````````````@`````
M````"`````````#?````"`````,`````````B*(```````"(D@```````"@`
M```````````````````(````````````````````Y`````$````P````````
M````````````B)(````````E`````````````````````0`````````!````
M`````.T````#``!P`````````````````````*V2````````4P``````````
M``````````$````````````````````!`````P``````````````````````
J````DP```````/\````````````````````!````````````````````
